==> jc-1.4.0.tar.gz: soot/toolkits/scalar/UnitValueBoxPair.h <==
// public class soot.toolkits.scalar.UnitValueBoxPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7edf91ee5ee80e6b soot_toolkits_scalar_UnitValueBoxPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_UnitValueBoxPair_H_
#define _JC_soot_toolkits_scalar_UnitValueBoxPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs	_jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs	_jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$refs	_jc_soot_toolkits_scalar_UnitValueBoxPair$refs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs	_jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object	_jc_soot_toolkits_scalar_UnitValueBoxPair$object;

typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods	_jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtable	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_UnitValueBoxPair$method$_init$3f2d211d40f4ed07(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_UnitValueBoxPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_toolkits_scalar_UnitValueBoxPair$method$getUnit$1c9f4c3a79dbf3ad(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *);
extern struct _jc_object *_jc_soot_toolkits_scalar_UnitValueBoxPair$method$getValueBox$421050120e132e82(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$getUnit$1c9f4c3a79dbf3ad;
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$getValueBox$421050120e132e82;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getUnit$1c9f4c3a79dbf3ad)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *);
	struct _jc_object	*(*getValueBox$421050120e132e82)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods	soot_toolkits_scalar_UnitValueBoxPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs {
	struct _jc_object	*unit;
	struct _jc_object	*valueBox;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$refs {
    _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs	soot_toolkits_scalar_UnitValueBoxPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs	soot_toolkits_scalar_UnitValueBoxPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object {
	_jc_soot_toolkits_scalar_UnitValueBoxPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype _jc_soot_toolkits_scalar_UnitValueBoxPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_UnitValueBoxPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_UnitValueBoxPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_UnitValueBoxPair_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/UnitValueBoxPair.h <==
// public class soot.toolkits.scalar.UnitValueBoxPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7edf91ee5ee80e6b soot_toolkits_scalar_UnitValueBoxPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_UnitValueBoxPair_H_
#define _JC_soot_toolkits_scalar_UnitValueBoxPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs	_jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs	_jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$refs	_jc_soot_toolkits_scalar_UnitValueBoxPair$refs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs	_jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object	_jc_soot_toolkits_scalar_UnitValueBoxPair$object;

typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods	_jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtable	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_UnitValueBoxPair$method$_init$3f2d211d40f4ed07(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_UnitValueBoxPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_scalar_UnitValueBoxPair$method$getUnit$1c9f4c3a79dbf3ad(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_scalar_UnitValueBoxPair$method$getValueBox$421050120e132e82(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$getUnit$1c9f4c3a79dbf3ad;
extern _jc_method _jc_soot_toolkits_scalar_UnitValueBoxPair$method_info$getValueBox$421050120e132e82;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnit$1c9f4c3a79dbf3ad)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getValueBox$421050120e132e82)(_jc_env *, struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vmethods	soot_toolkits_scalar_UnitValueBoxPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs {
	struct _jc_object	*unit;
	struct _jc_object	*valueBox;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$refs {
    _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_refs	soot_toolkits_scalar_UnitValueBoxPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_UnitValueBoxPair$sub_nonrefs	soot_toolkits_scalar_UnitValueBoxPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_UnitValueBoxPair$object {
	_jc_soot_toolkits_scalar_UnitValueBoxPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_UnitValueBoxPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_UnitValueBoxPair$vtype _jc_soot_toolkits_scalar_UnitValueBoxPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_UnitValueBoxPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_UnitValueBoxPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_UnitValueBoxPair_H_ */
